@@ -11,31 +11,46 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-//use async_trait::async_trait;
-use std::collections::{HashMap, HashSet, VecDeque};
-use std::fmt;
-use std::io::{self, Error, ErrorKind};
-use std::mem;
-use std::pin::Pin;
-use std::sync::atomic::{AtomicBool, Ordering};
-use std::sync::Arc;
-use std::task::{Context, Poll};
-use std::time::{Duration, Instant};
-
-//use crossbeam_channel as channel;
-use tokio::io::{AsyncWrite, AsyncWriteExt};
-use tokio::{io::BufReader, io::BufWriter, sync::Mutex};
-
-use crate::connector::{Connector, NatsStream, ServerAddress};
-use crate::message::Message;
-use crate::proto::{self, ClientOp, ServerOp};
-use crate::BoxFuture;
-use crate::{header::HeaderMap, inject_delay, inject_io_failure, Options, ServerInfo};
+use crate::{
+    connector::{Connector, NatsStream, ServerAddress},
+    header::HeaderMap,
+    inject_delay, inject_io_failure,
+    message::Message,
+    proto::{self, ClientOp, ServerOp},
+    BoxFuture, Options, ServerInfo,
+};
+#[cfg(not(feature = "otel"))]
+use log::{debug, error};
+use std::{
+    collections::{HashMap, HashSet, VecDeque},
+    fmt,
+    io::{self, Error, ErrorKind},
+    mem,
+    pin::Pin,
+    sync::{
+        atomic::{AtomicBool, Ordering},
+        Arc,
+    },
+    task::{Context, Poll},
+    time::{Duration, Instant},
+};
+use tokio::{
+    io::{AsyncWrite, AsyncWriteExt, BufReader, BufWriter},
+    sync::Mutex,
+};
+#[cfg(feature = "otel")]
+use tracing::{debug, error};
 
 const BUF_CAPACITY: usize = 32 * 1024;
 /// maximum messages to queue before applying backpressure
 const MAX_SUBSCRIPTION_QUEUE: usize = 650;
 
+const PING_FLUSH_TIMEOUT_SEC: u64 = 40;
+
+// TODO(dlc) - Make configurable.
+const PING_INTERVAL: Duration = Duration::from_secs(20); // was 120 sec
+const MAX_PINGS_OUT: u8 = 2;
+
 /// Client state.
 ///
 /// NB: locking protocol - writes must ALWAYS be locked
@@ -88,24 +103,12 @@ struct ReadState {
 }
 
 /// A handler for preprocess messages for a subscription as they arrive over the wire.
-//#[async_trait]
-//pub(crate) trait Preprocessor: Send + Sync {
-//    async fn process(&self, sid: u64, msg: &Message) -> bool;
-//}
-//#[async_trait]
 pub(crate) trait Preprocessor: Send + Sync {
     fn process<'proc>(&'proc self, sid: u64, msg: &'proc Message) -> BoxFuture<'proc, bool>;
 }
 
 #[derive(Debug, Default, Clone)]
 struct NoProcessing {}
-//#[async_trait]
-//impl<'p> Preprocessor for NoProcessing {
-//    async fn process(&self, _sid: u64, _msg: &Message) -> bool {
-//        false
-//    }
-//}
-//#[async_trait]
 impl<'p> Preprocessor for NoProcessing {
     fn process(&self, _sid: u64, _msg: &Message) -> BoxFuture<'static, bool> {
         Box::pin(async { false })
@@ -139,12 +142,13 @@ pub struct Client {
 impl Client {
     /// Creates a new client that will begin connecting in the background.
     pub(crate) async fn connect(urls: Vec<ServerAddress>, options: Options) -> io::Result<Client> {
+        crate::init_tracing();
         // A channel for coordinating flushes.
-        let (flush_kicker, mut flush_wanted) = tokio::sync::mpsc::channel(1);
+        let (flush_kicker, mut flush_wanted) = tokio::sync::mpsc::channel(10);
 
         // Channels for coordinating initial connect.
         let (run_sender, run_receiver) = tokio::sync::oneshot::channel();
-        let (pong_sender, mut pong_receiver) = tokio::sync::mpsc::channel(1);
+        let (pong_sender, mut pong_receiver) = tokio::sync::mpsc::channel(10);
 
         // The client state.
         let _client = Client {
@@ -216,9 +220,6 @@ impl Client {
             const MIN_FLUSH_BETWEEN: Duration = Duration::from_millis(5);
 
             // Handle recv timeouts and check if we should send a PING.
-            // TODO(dlc) - Make configurable.
-            const PING_INTERVAL: Duration = Duration::from_secs(2 * 60);
-            const MAX_PINGS_OUT: u8 = 2;
 
             let mut last = Instant::now() - MIN_FLUSH_BETWEEN;
 
@@ -318,6 +319,9 @@ impl Client {
                 }
             }
 
+            if let Err(e) = write.flush_kicker.send(()).await {
+                debug!("error triggering flush {}", e);
+            }
             // Enqueue an expected PONG.
             let mut read = self.state.read.lock().await;
             read.pongs.push_back(sender);
@@ -330,9 +334,21 @@ impl Client {
         };
 
         // Wait until the PONG operation is received.
-        match pong.recv().await {
-            Some(()) => Ok(()),
-            None => Err(Error::new(ErrorKind::ConnectionReset, "flush failed")),
+        match tokio::time::timeout(Duration::from_secs(PING_FLUSH_TIMEOUT_SEC), pong.recv()).await {
+            Err(_) => {
+                // if socket is closed, don't fail
+                //error!("ping flush timed out after {} sec", PING_FLUSH_TIMEOUT_SEC);
+                //Err(Error::new(ErrorKind::ConnectionReset, "flush failed"))
+                Ok(())
+            }
+            Ok(Some(())) => Ok(()),
+            Ok(None) => {
+                error!("ping sender quit unexpectedly");
+                Err(Error::new(
+                    ErrorKind::ConnectionReset,
+                    "flush failed - ping sender quit",
+                ))
+            }
         }
     }
 
@@ -394,18 +410,22 @@ impl Client {
     pub(crate) async fn subscribe(
         &self,
         subject: &str,
-        queue_group: Option<&str>,
+        queue_group: Option<String>,
     ) -> io::Result<(u64, crate::subscription::SubscriptionReceiver<Message>)> {
         // Inject random delays when testing.
-        self.subscribe_with_preprocessor(subject, queue_group, Box::pin(NoProcessing::default()))
-            .await
+        self.subscribe_with_preprocessor(
+            subject.to_string(),
+            queue_group,
+            Box::pin(NoProcessing::default()),
+        )
+        .await
     }
 
     /// Subscribe to a subject with a message preprocessor.
-    pub(crate) async fn subscribe_with_preprocessor<'a>(
+    pub(crate) async fn subscribe_with_preprocessor(
         &self,
-        subject: &str,
-        queue_group: Option<&str>,
+        subject: String,
+        queue_group: Option<String>,
         message_processor: Pin<Box<dyn Preprocessor>>,
     ) -> io::Result<(u64, crate::subscription::SubscriptionReceiver<Message>)> {
         inject_delay().await;
@@ -422,9 +442,10 @@ impl Client {
 
         // If connected, send a SUB operation.
         if let Some(writer) = write.writer.as_mut() {
+            let queue_group = queue_group.as_ref();
             let op = ClientOp::Sub {
-                subject,
-                queue_group,
+                subject: &subject,
+                queue_group: queue_group.map(|s| s.as_str()),
                 sid,
             };
             proto::encode(writer, op).await?;
@@ -436,8 +457,8 @@ impl Client {
         read.subscriptions.insert(
             sid,
             Subscription {
-                subject: subject.to_string(),
-                queue_group: queue_group.map(ToString::to_string),
+                subject,
+                queue_group,
                 messages: sender,
                 preprocess: message_processor,
             },
