@@ -53,8 +53,8 @@ pub(crate) struct Connector {
 }
 
 /// load tls certs. This function uses blocking file io.
-/// load_native_certs could load a 300KB file (per docs.rs/rustls-native-certs)
-fn load_tls_certs(tls_options: Arc<Options>) -> io::Result<ClientConfig> {
+/// `load_native_certs` could load a 300KB file (per docs.rs/rustls-native-certs)
+fn load_tls_certs(tls_options: &Arc<Options>) -> io::Result<ClientConfig> {
     // Include system root certificates.
     //
     // On Windows, some certificates cannot be loaded by rustls
@@ -103,7 +103,8 @@ impl Connector {
         options: Arc<Options>,
     ) -> io::Result<Connector> {
         let tls_options = options.clone();
-        let tls_config = tokio::task::spawn_blocking(move || load_tls_certs(tls_options)).await??;
+        let tls_config =
+            tokio::task::spawn_blocking(move || load_tls_certs(&tls_options)).await??;
 
         let connector = Connector {
             attempts: urls.into_iter().map(|url| (url, 0)).collect(),
@@ -412,15 +413,19 @@ impl NatsStream {
 
     /// Will attempt to shutdown the underlying stream.
     pub(crate) async fn shutdown(&mut self) {
-        match Arc::<Flavor>::get_mut(&mut self.flavor).unwrap() {
-            Flavor::Tcp(tcp) => {
+        match Arc::<Flavor>::get_mut(&mut self.flavor) {
+            Some(Flavor::Tcp(tcp)) => {
                 let tcp = tcp.get_mut();
                 let _ = tcp.shutdown().await;
             }
-            Flavor::Tls(tls) => {
+            Some(Flavor::Tls(tls)) => {
                 let tls = tls.get_mut();
                 let _ = tls.get_mut().0.shutdown().await;
             }
+            None => {
+                // more than one Arc holder: can't shut down yet
+                log::warn!("connection shutdown deferred");
+            }
         }
     }
 }
