@@ -100,11 +100,11 @@
 //!
 
 use crate::{BoxFuture, Stream};
+#[cfg(not(feature = "otel"))]
+use log::{debug, error};
 use pin_project::pin_project;
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use serde_repr::{Deserialize_repr, Serialize_repr};
-use std::sync::atomic::{AtomicU64, Ordering};
-use std::sync::Arc;
 use std::{
     collections::{HashSet, VecDeque},
     convert::TryFrom,
@@ -112,9 +112,15 @@ use std::{
     fmt::Debug,
     io::{self, ErrorKind},
     pin::Pin,
+    sync::{
+        atomic::{AtomicU64, Ordering},
+        Arc,
+    },
     time::Duration,
 };
 use tokio::sync::Mutex;
+#[cfg(feature = "otel")]
+use tracing::{debug, error};
 
 const ORDERED_IDLE_HEARTBEAT: Duration = Duration::from_nanos(5_000_000_000);
 
@@ -557,15 +563,20 @@ impl crate::client::Preprocessor for SubscriptionPreprocessor {
                     .and_then(|headers| {
                         headers
                             .get(header::NATS_CONSUMER_STALLED)
-                            .map(|set| set.iter().cloned().next())
+                            .map(|set| set.iter().next().cloned())
                     })
                     .flatten();
 
                 if let Some(consumer_stalled) = maybe_consumer_stalled {
-                    self.context
+                    debug!("publish on stalled idle heartbeat");
+                    if let Some(Err(e)) = self
+                        .context
                         .connection
                         .try_publish_with_reply_or_headers(&consumer_stalled, None, None, b"")
-                        .await;
+                        .await
+                    {
+                        error!("try_publish errored: {}", e);
+                    }
                 }
 
                 let maybe_consumer_seq = message
@@ -574,7 +585,7 @@ impl crate::client::Preprocessor for SubscriptionPreprocessor {
                     .and_then(|headers| {
                         headers
                             .get(header::NATS_LAST_CONSUMER)
-                            .map(|set| set.iter().cloned().next())
+                            .map(|set| set.iter().next().cloned())
                     })
                     .flatten();
 
@@ -698,7 +709,6 @@ impl JetStream {
                     .inner
                     .entry(header::NATS_MSG_ID.to_string())
                     .or_insert_with(HashSet::default);
-
                 entry.insert(v.to_string());
             }
 
@@ -707,7 +717,6 @@ impl JetStream {
                     .inner
                     .entry(header::NATS_EXPECTED_LAST_MSG_ID.to_string())
                     .or_insert_with(HashSet::default);
-
                 entry.insert(v.to_string());
             }
 
@@ -716,7 +725,6 @@ impl JetStream {
                     .inner
                     .entry(header::NATS_EXPECTED_STREAM.to_string())
                     .or_insert_with(HashSet::default);
-
                 entry.insert(v.to_string());
             }
 
@@ -725,7 +733,6 @@ impl JetStream {
                     .inner
                     .entry(header::NATS_EXPECTED_LAST_SEQUENCE.to_string())
                     .or_insert_with(HashSet::default);
-
                 entry.insert(v.to_string());
             }
 
@@ -734,7 +741,6 @@ impl JetStream {
                     .inner
                     .entry(header::NATS_EXPECTED_LAST_SUBJECT_SEQUENCE.to_string())
                     .or_insert_with(HashSet::default);
-
                 entry.insert(v.to_string());
             }
 
@@ -772,7 +778,7 @@ impl JetStream {
     /// use nats_aflowt::Stream;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # let sub_name = format!("sub_{}", rand::random::<u64>());
     /// # context.add_stream(sub_name.as_str()).await?;
@@ -798,7 +804,7 @@ impl JetStream {
     /// # use nats_aflowt::jetstream::{ SubscribeOptions };
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let js = nats_aflowt::jetstream::new(nc);
     /// let sub = js.subscribe_with_options("foo",
     ///       &SubscribeOptions::bind("existing_stream".to_string(),
@@ -822,9 +828,9 @@ impl JetStream {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
-    /// # context.add_stream("queue");
+    /// # context.add_stream("queue").await;
     /// let subscription = context.queue_subscribe("queue", "queue_group").await?;
     /// # Ok(())
     /// # }
@@ -834,7 +840,8 @@ impl JetStream {
         subject: &str,
         queue: &str,
     ) -> io::Result<PushSubscription> {
-        self.do_push_subscribe(subject, Some(queue), None).await
+        self.do_push_subscribe(subject, Some(queue.to_string()), None)
+            .await
     }
 
     /// Creates a push-based consumer subscription with a queue group and options.
@@ -848,7 +855,7 @@ impl JetStream {
         queue: &str,
         options: &SubscribeOptions,
     ) -> io::Result<PushSubscription> {
-        self.do_push_subscribe(subject, Some(queue), Some(options))
+        self.do_push_subscribe(subject, Some(queue.to_string()), Some(options))
             .await
     }
 
@@ -902,7 +909,7 @@ impl JetStream {
     async fn do_push_subscribe(
         &self,
         subject: &str,
-        maybe_queue: Option<&str>,
+        maybe_queue: Option<String>,
         maybe_options: Option<&SubscribeOptions>,
     ) -> io::Result<PushSubscription> {
         // If no stream name is specified the subject cannot be empty.
@@ -1002,7 +1009,7 @@ impl JetStream {
             }
 
             if let Some(deliver_group) = info.config.deliver_group.as_ref() {
-                if let Some(queue) = maybe_queue {
+                if let Some(queue) = &maybe_queue {
                     if deliver_group != queue {
                         return Err(io::Error::new(
                             io::ErrorKind::Other,
@@ -1192,9 +1199,10 @@ impl JetStream {
         }?;
 
         // Figure out if we have a consumer name
+        #[allow(clippy::or_fun_call)]
         let maybe_durable_name = maybe_options
             .and_then(|options| options.durable_name.as_deref())
-            .or(maybe_queue);
+            .or(maybe_queue.as_deref());
 
         let maybe_consumer_name = maybe_options
             .and_then(|options| options.consumer_name.as_deref())
@@ -1266,7 +1274,7 @@ impl JetStream {
             config.filter_subject = subject.to_string();
 
             // Pass the queue to the consumer config
-            if let Some(queue) = maybe_queue {
+            if let Some(queue) = &maybe_queue {
                 if config.durable_name.is_none() {
                     config.durable_name = Some(queue.to_owned());
                 }
@@ -1329,8 +1337,8 @@ impl JetStream {
             .0
             .client
             .subscribe_with_preprocessor(
-                &deliver_subject,
-                maybe_queue,
+                deliver_subject,
+                maybe_queue.clone(),
                 Box::pin(preprocessor.clone()),
             )
             .await?;
@@ -1383,7 +1391,7 @@ impl JetStream {
                         .0
                         .client
                         .subscribe_with_preprocessor(
-                            deliver_subject,
+                            deliver_subject.to_string(),
                             maybe_queue,
                             Box::pin(preprocessor),
                         )
@@ -1749,6 +1757,10 @@ impl JetStream {
         Res: DeserializeOwned,
     {
         let res_msg = self.connection.request(subject, req).await?;
+        assert!(
+            !res_msg.data.is_empty(),
+            "js_request received empty response"
+        );
         let res: ApiResponse<Res> = serde_json::de::from_slice(&res_msg.data)?;
         match res {
             ApiResponse::Ok(stream_info) => Ok(stream_info),
