@@ -12,16 +12,26 @@
 // limitations under the License.
 
 use crate::Stream;
-use std::io;
-use std::pin::Pin;
-use std::sync::atomic::{AtomicU64, Ordering};
-use std::sync::Arc;
-use std::thread;
-use std::time::Duration;
+#[cfg(not(feature = "otel"))]
+use log::error;
+use std::{
+    io,
+    pin::Pin,
+    sync::{
+        atomic::{AtomicU64, Ordering},
+        Arc,
+    },
+    thread,
+    time::Duration,
+};
+#[cfg(feature = "otel")]
+use tracing::error;
 
-use crate::jetstream::{AckPolicy, ConsumerInfo, ConsumerOwnership, JetStream};
-use crate::message::Message;
-use crate::DEFAULT_FLUSH_TIMEOUT;
+use crate::{
+    jetstream::{AckPolicy, ConsumerInfo, ConsumerOwnership, JetStream},
+    message::Message,
+    DEFAULT_FLUSH_TIMEOUT,
+};
 
 #[derive(Debug)]
 pub(crate) struct Inner {
@@ -118,7 +128,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # let name=format!("next_{}", rand::random::<u64>());
     /// # context.add_stream(name.as_str()).await?;
@@ -155,7 +165,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
     /// # context.add_stream("try_next").await?;
@@ -175,7 +185,9 @@ impl PushSubscription {
                     }
                     return Some(message);
                 }
-                None => return None,
+                None => {
+                    return None;
+                }
             }
         }
     }
@@ -188,9 +200,11 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
-    /// # let subscription = context.subscribe("foo").await?;
+    /// # let name = format!("sub_{}", rand::random::<u64>());
+    /// # context.add_stream(name.as_str()).await?;
+    /// # let subscription = context.subscribe(name.as_str()).await?;
     /// if let Ok(message) = subscription.next_timeout(std::time::Duration::from_secs(1)).await {
     ///     println!("Received {}", message);
     /// }
@@ -231,7 +245,7 @@ impl PushSubscription {
     /// use futures::stream::StreamExt;
     /// #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("messages-100").await?;
     /// let mut subscription = context.subscribe("messages-100").await?.messages();
@@ -264,7 +278,7 @@ impl PushSubscription {
     /// use futures::stream::StreamExt;
     /// #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("stream").await?;
     /// let mut sub = context.subscribe("stream").await?.stream();
@@ -290,7 +304,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("with_handler").await?;
     /// context.subscribe("with_handler").await?.with_handler(move |message| {
@@ -303,11 +317,25 @@ impl PushSubscription {
     /// ```
     pub fn with_handler<F>(self, handler: F) -> Handler
     where
-        F: Fn(Message) -> io::Result<()> + Send + 'static,
+        F: Fn(Message) -> io::Result<()> + Send + Sync + 'static,
     {
         // This will allow us to not have to capture the return. When it is
         // dropped it will not unsubscribe from the server.
         let sub = self.clone();
+        let handler = Arc::new(handler);
+        tokio::spawn(async move {
+            while let Some(m) = sub.next().await {
+                let handler = handler.clone();
+                let _ = tokio::task::spawn_blocking(move || {
+                    if let Err(e) = handler(m) {
+                        // TODO(dlc) - Capture for last error?
+                        log::error!("Error in callback! {:?}", e);
+                    }
+                });
+            }
+        });
+        /*
+
         thread::Builder::new()
             .name(format!(
                 "nats_jetstream_push_subscriber_{}_{}",
@@ -316,14 +344,18 @@ impl PushSubscription {
             .spawn(move || {
                 futures::executor::block_on(async {
                     while let Some(m) = sub.next().await {
-                        if let Err(e) = handler(m) {
-                            // TODO(dlc) - Capture for last error?
-                            log::error!("Error in callback! {:?}", e);
-                        }
+                        let handler = handler.clone();
+                        let _ = tokio::spawn(async move {
+                            if let Err(e) = handler(m) {
+                                // TODO(dlc) - Capture for last error?
+                                log::error!("Error in callback! {:?}", e);
+                            }
+                        });
                     }
                 })
             })
             .expect("threads should be spawn-able");
+        */
         Handler { subscription: self }
     }
 
@@ -335,28 +367,31 @@ impl PushSubscription {
     ///
     /// # Example
     /// ```
-    /// #![feature(async_closure)]
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let sub = nc.subscribe("foo").await?
-    ///      .with_async_handler( async move |m| { m.respond("ans=42").await?; Ok(()) });
+    ///      .with_async_handler( move |m| async move { m.respond("ans=42").await?; Ok(()) });
     /// # Ok(())
     /// # }
     /// ```
-    #[allow(clippy::return_self_not_must_use)]
+    #[must_use]
     pub fn with_async_handler<F, T>(self, handler: F) -> Self
     where
         F: Fn(Message) -> T + 'static + Send + Sync,
         T: futures::Future<Output = io::Result<()>> + Send,
     {
         let sub = self.clone();
+        let handler = Arc::new(Box::new(handler));
         tokio::spawn(async move {
             while let Some(m) = sub.next().await {
-                if let Err(e) = handler(m).await {
-                    // TODO(dlc) - Capture for last error?
-                    log::error!("Error in callback! {:?}", e);
-                }
+                let handler = handler.clone();
+                let _ = tokio::spawn(async move {
+                    if let Err(e) = handler(m).await {
+                        // TODO(dlc) - Capture for last error?
+                        log::error!("Error in callback! {:?}", e);
+                    }
+                });
             }
         });
         self
@@ -374,7 +409,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("with_process_handler").await;
     /// context.subscribe("with_process_handler").await?.with_process_handler(|message| {
@@ -387,13 +422,14 @@ impl PushSubscription {
     /// ```
     pub fn with_process_handler<F>(self, handler: F) -> Handler
     where
-        F: Fn(&Message) -> io::Result<()> + Send + 'static,
+        F: Fn(&Message) -> io::Result<()> + Send + Sync + 'static,
     {
         let consumer_ack_policy = self.0.consumer_ack_policy;
 
         // This will allow us to not have to capture the return. When it is
         // dropped it will not unsubscribe from the server.
         let sub = self.clone();
+        let handler = Arc::new(Box::new(handler));
         thread::Builder::new()
             .name(format!(
                 "nats_push_subscriber_{}_{}",
@@ -402,15 +438,18 @@ impl PushSubscription {
             .spawn(move || {
                 futures::executor::block_on(async {
                     while let Some(message) = sub.next().await {
-                        if let Err(err) = handler(&message) {
-                            log::error!("Error in callback! {:?}", err);
-                        }
-
-                        if consumer_ack_policy != AckPolicy::None {
-                            if let Err(err) = message.ack().await {
+                        let handler = handler.clone();
+                        let _ = tokio::spawn(async move {
+                            if let Err(err) = handler(&message) {
                                 log::error!("Error in callback! {:?}", err);
                             }
-                        }
+
+                            if consumer_ack_policy != AckPolicy::None {
+                                if let Err(err) = message.ack().await {
+                                    log::error!("Error in callback! {:?}", err);
+                                }
+                            }
+                        });
                     }
                 })
             })
@@ -419,7 +458,7 @@ impl PushSubscription {
     }
 
     /// Process and acknowledge a single message, waiting indefinitely for
-    /// one to arrive.
+    /// one to arrive. Caution: This should not be used with blocking io.
     ///
     /// Does not acknowledge the processed message if the closure returns an `Err`.
     ///
@@ -428,14 +467,13 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
-    /// # let sub_name=format!("process_{}", rand::random::<u64>());
+    /// # let sub_name = format!("process_{}", rand::random::<u64>());
     /// # context.add_stream(sub_name.as_str()).await?;
-    /// # context.publish(&sub_name, "hello").await?;
-    /// # context.publish(&sub_name, "hello2").await?;
-    /// #
     /// # let mut subscription = context.subscribe(&sub_name).await?;
+    /// # context.publish(&sub_name, "hello").await?;
+    /// #
     /// subscription.process(|message| {
     ///     println!("Received message {:?}", message);
     ///     Ok(())
@@ -443,15 +481,33 @@ impl PushSubscription {
     /// # Ok(())
     /// # }
     /// ```
-    pub async fn process<R, F: Fn(&Message) -> io::Result<R>>(&mut self, f: F) -> io::Result<R> {
-        //TODO(ss): remove unwrap and return error if next() returns None
-        let next = self.next().await.unwrap();
-        let result = f(&next)?;
-        if self.0.consumer_ack_policy != AckPolicy::None {
-            next.ack().await?;
+    pub async fn process<R: Send + 'static, F: Fn(&Message) -> io::Result<R> + Send + Sync>(
+        &mut self,
+        f: F,
+    ) -> io::Result<R>
+    where
+        F: 'static,
+    {
+        let ack_policy = self.0.consumer_ack_policy;
+        match self.next().await {
+            Some(next) => tokio::task::spawn(async move {
+                // calling f() may block the tokio executor if f blocks.
+                // the executor is not blocked for the call to next() or the ack()
+                let result = f(&next);
+                if ack_policy != AckPolicy::None {
+                    if let Err(e) = next.ack().await {
+                        error!("ack error: {}", e);
+                    }
+                }
+                result
+            })
+            .await
+            .map_err(|e| io::Error::new(io::ErrorKind::Other, format!("join error: {}", e)))?,
+            _ => Err(io::Error::new(
+                io::ErrorKind::Other,
+                "process: unsubscribed",
+            )),
         }
-
-        Ok(result)
     }
 
     /// Process and acknowledge a single message, waiting up to timeout configured `timeout` before
@@ -465,7 +521,7 @@ impl PushSubscription {
     /// # use std::time::Duration;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("process_timeout").await?;
     /// # context.publish("process_timeout", "hello").await?;
@@ -501,7 +557,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
     /// # context.add_stream("foo").await?;
@@ -526,7 +582,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("unsubscribe").await?;
     /// #
@@ -578,7 +634,7 @@ impl PushSubscription {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # context.add_stream("close").await?;
     /// let subscription = context.subscribe("close").await?;
@@ -590,8 +646,6 @@ impl PushSubscription {
         self.unsubscribe().await
     }
 
-    // TODO(ss): unexplained: I was getting hangs on this doc test, then I
-    //    changed the sub_name to have a random component and it seems to work
     /// Send an unsubscription then flush the connection,
     /// allowing any unprocessed messages to be handled
     /// by a handler function if one is configured.
@@ -609,9 +663,10 @@ impl PushSubscription {
     /// # Example
     ///
     /// ```
+    /// # use std::time::Duration;
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// # let sub_name = format!("drain_{}", rand::random::<u32>());
     /// # context.add_stream(sub_name.as_str()).await?;
@@ -622,8 +677,8 @@ impl PushSubscription {
     ///
     /// subscription.drain().await?;
     ///
-    /// assert!(subscription.next().await.is_none());
-    ///
+    /// # // there are no more messages in subscription
+    /// # assert!(subscription.next_timeout(Duration::from_secs(2)).await.is_err(), "emtpy");
     /// # Ok(())
     /// # }
     /// ```
@@ -673,7 +728,7 @@ impl Handler {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let sub = nc.subscribe("foo").await?.with_handler(move |msg| {
     ///     println!("Received {}", &msg);
     ///     Ok(())
