@@ -13,12 +13,11 @@
 
 use crate::header::HeaderMap;
 use serde::{Deserialize, Serialize};
-use std::convert::TryFrom;
-use std::io;
-use std::time::Duration;
+use std::{convert::TryFrom, io, time::Duration};
+use time::serde::rfc3339;
 
 /// A UTC time
-pub type DateTime = chrono::DateTime<chrono::Utc>;
+pub type DateTime = time::OffsetDateTime;
 
 #[derive(Serialize)]
 pub(crate) struct StreamMessageGetRequest {
@@ -49,7 +48,7 @@ pub struct RawStreamMessage {
     pub headers: Option<String>,
 
     /// The time the message was published.
-    #[serde(rename = "time")]
+    #[serde(rename = "time", with = "rfc3339")]
     pub time: DateTime,
 }
 
@@ -203,7 +202,7 @@ pub struct ConsumerConfig {
     pub opt_start_seq: Option<u64>,
     /// Used in combination with `DeliverPolicy::ByStartTime` to only select messages arriving
     /// after this time.
-    #[serde(default, skip_serializing_if = "is_default")]
+    #[serde(default, skip_serializing_if = "is_default", with = "rfc3339::option")]
     pub opt_start_time: Option<DateTime>,
     /// How messages should be acknowledged
     pub ack_policy: AckPolicy,
@@ -347,6 +346,7 @@ pub struct StreamInfo {
     /// The configuration associated with this stream
     pub config: StreamConfig,
     /// The time that this stream was created
+    #[serde(with = "rfc3339")]
     pub created: DateTime,
     /// Various metrics associated with this stream
     pub state: StreamState,
@@ -387,10 +387,12 @@ pub struct StreamState {
     /// The lowest sequence number still present in this stream
     pub first_seq: u64,
     /// The time associated with the oldest message still present in this stream
+    #[serde(with = "rfc3339")]
     pub first_ts: DateTime,
     /// The last sequence number assigned to a message in this stream
     pub last_seq: u64,
     /// The time that the last message was received by this stream
+    #[serde(with = "rfc3339")]
     pub last_ts: DateTime,
     /// The number of consumers configured to consume this stream
     pub consumer_count: usize,
@@ -643,6 +645,7 @@ pub struct ConsumerInfo {
     /// The consumer's unique name
     pub name: String,
     /// The time the consumer was created
+    #[serde(with = "rfc3339")]
     pub created: DateTime,
     /// The consumer's configuration
     pub config: ConsumerConfig,
