@@ -15,18 +15,17 @@
 //! This feature is experimental and the API may change.
 
 use futures::StreamExt;
-use std::io;
-use std::pin::Pin;
-use std::time::Duration;
+use std::{io, pin::Pin, time::Duration};
 
-use crate::header::{self, HeaderMap};
-use crate::jetstream::{
-    DateTime, Error, ErrorCode, JetStream, StorageType, StreamConfig, StreamInfo, StreamMessage,
-    SubscribeOptions,
+use crate::{
+    header::{self, HeaderMap},
+    jetstream::{
+        DateTime, Error, ErrorCode, JetStream, StorageType, StreamConfig, StreamInfo,
+        StreamMessage, SubscribeOptions,
+    },
 };
 
-use crate::message::Message;
-use crate::Stream;
+use crate::{message::Message, Stream};
 use lazy_static::lazy_static;
 use regex::Regex;
 use std::collections::HashSet;
@@ -117,13 +116,13 @@ impl JetStream {
     /// # Example
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// context.create_key_value(&Config {
+    /// context.create_key_value(&kv::Config {
     ///   bucket: "key_value".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -176,13 +175,13 @@ impl JetStream {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_key_value(&Config {
+    /// let bucket = context.create_key_value(&kv::Config {
     ///   bucket: "create_key_value".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -255,13 +254,13 @@ impl JetStream {
     /// # Example
     ///
     /// ```
-    /// use nats_aflowt::kv::Config;
+    /// use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "delete_key_value".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -335,20 +334,19 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "entry".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
     /// #
     /// bucket.put("foo", b"bar").await?;
-    /// let maybe_entry = bucket.entry("foo").await?;
-    /// if let Some(entry) = maybe_entry {
+    /// if let Some(entry) = bucket.entry("foo").await? {
     ///   println!("Found entry {:?}", entry);
     /// }
     /// #
@@ -391,7 +389,6 @@ impl Store {
                         }
                     }
                 }
-
                 Err(err)
             }
         }
@@ -402,13 +399,13 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "get".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -438,13 +435,13 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "get".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -473,19 +470,20 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
+    /// # let name = format!("bucket_create_{}", rand::random::<u64>());
     /// #
-    /// # let bucket = context.create_key_value(&Config {
-    /// #  bucket: "create".to_string(),
+    /// # let bucket = context.create_key_value(&kv::Config {
+    /// #  bucket: name.clone(),
     /// #  ..Default::default()
     /// # }).await?;
     /// #
-    /// bucket.purge("foo").await?;
     /// bucket.create("foo", b"bar").await?;
+    /// bucket.purge("foo").await?;
     /// #
     /// # Ok(())
     /// # }
@@ -511,13 +509,13 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "update".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -561,13 +559,13 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "delete".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -606,14 +604,14 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
-    /// #
-    /// # let bucket = context.create_key_value(&Config {
-    /// #  bucket: "purge".to_string(),
+    /// # let name = format!("bucket_purge_{}", rand::random::<u64>());
+    /// # let bucket = context.create_key_value(&kv::Config {
+    /// #  bucket: name,
     /// #  ..Default::default()
     /// # }).await?;
     /// #
@@ -658,14 +656,14 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// use futures::stream::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// # let bucket = context.create_key_value(&Config {
+    /// # let bucket = context.create_key_value(&kv::Config {
     /// #  bucket: "keys".to_string(),
     /// #  ..Default::default()
     /// # }).await?;
@@ -707,14 +705,14 @@ impl Store {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::kv::Config;
+    /// # use nats_aflowt::kv;
     /// use futures::stream::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_key_value(&Config {
+    /// let bucket = context.create_key_value(&kv::Config {
     ///   bucket: "history_iter".to_string(),
     ///   history: 2,
     ///   ..Default::default()
@@ -833,6 +831,10 @@ impl Keys {
                     if operation != Operation::Put {
                         continue;
                     }
+                    //if message.data.is_empty() {
+                    //    self.done = true;
+                    //    break;
+                    //}
 
                     if let Some(m) = message
                         .subject
