@@ -35,7 +35,7 @@
 //! ```no_run
 //! # #[tokio::main]
 //! # async fn main() -> Result<(), Box<dyn std::error::Error>> {
-//! let nc = nats_aflowt::connect("demo.nats.io").await?;
+//! let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
 //!
 //! let nc2 = nats_aflowt::Options::with_user_pass("derek", "s3cr3t!")
 //!     .with_name("My Rust NATS App")
@@ -55,7 +55,7 @@
 //! ```
 //! # #[tokio::main]
 //! # async fn main() -> std::io::Result<()> {
-//! let nc = nats_aflowt::connect("demo.nats.io").await?;
+//! let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
 //! nc.publish("my.subject", "Hello World!").await?;
 //!
 //! nc.publish("my.subject", "my message").await?;
@@ -74,7 +74,7 @@
 //! # #[tokio::main]
 //! # async fn main() -> std::io::Result<()> {
 //! # use std::time::Duration;
-//! let nc = nats_aflowt::connect("demo.nats.io").await?;
+//! let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
 //! let mut sub = nc.subscribe("foo").await?.stream();
 //!
 //! // use as Stream
@@ -100,7 +100,7 @@
 //! # use futures::stream::StreamExt;
 //! # #[tokio::main]
 //! # async fn main() -> std::io::Result<()> {
-//! let nc = nats_aflowt::connect("demo.nats.io").await?;
+//! let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
 //! let resp = nc.request("foo", "Help me?").await?;
 //!
 //! // With a timeout.
@@ -170,7 +170,6 @@
     clippy::needless_borrow,
     clippy::needless_continue,
     clippy::needless_pass_by_value,
-    clippy::non_ascii_literal,
     clippy::path_buf_push_overwrite,
     clippy::print_stdout,
     clippy::single_match_else,
@@ -193,32 +192,19 @@
     clippy::module_name_repetitions
 )]
 
-/// Async-enabled NATS client.
-//pub mod _asynk;
 mod auth_utils;
 mod client;
 mod connect;
 mod connector;
+pub mod header;
 mod message;
 mod options;
 mod proto;
 mod secure_wipe;
 mod subscription;
-
-/// Header constants and types.
-pub mod header;
-
-pub use futures::future::BoxFuture;
-/// Stream, as used by this crate. re-export of `futures::Stream`
-pub use futures::Stream;
-
-/// `JetStream` stream management and consumers.
+pub use futures::{future::BoxFuture, Stream}; // re-export of futures::Stream
 pub mod jetstream;
-
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable")))]
 pub mod kv;
-
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable")))]
 pub mod object_store;
 
 #[cfg(feature = "fault_injection")]
@@ -372,7 +358,7 @@ impl Drop for Inner {
 /// ```
 /// # #[tokio::main]
 /// # async fn main() -> std::io::Result<()> {
-/// let nc = nats_aflowt::connect("demo.nats.io").await?;
+/// let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
 /// # Ok::<(), std::io::Error>(())
 /// # }
 /// ```
@@ -406,7 +392,7 @@ impl Drop for Inner {
 ///
 /// #[derive(Debug, StructOpt)]
 /// struct Config {
-///     #[structopt(short, long = "server", default_value = "demo.nats.io")]
+///     #[structopt(short, long = "server", default_value = "127.0.0.1:14222")]
 ///     servers: Vec<ServerAddress>,
 /// }
 /// #[tokio::main]
@@ -428,6 +414,7 @@ impl Connection {
     where
         I: IntoServerList,
     {
+        crate::init_tracing();
         let urls = urls.into_server_list()?;
         let client = Client::connect(urls, options).await?;
         client.flush(DEFAULT_FLUSH_TIMEOUT).await?;
@@ -440,7 +427,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let sub = nc.subscribe("foo").await?;
     /// # Ok(())
     /// # }
@@ -455,13 +442,13 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let sub = nc.queue_subscribe("foo", "production").await?;
     /// # Ok(())
     /// # }
     /// ```
     pub async fn queue_subscribe(&self, subject: &str, queue: &str) -> io::Result<Subscription> {
-        self.do_subscribe(subject, Some(queue)).await
+        self.do_subscribe(subject, Some(queue.to_string())).await
     }
 
     /// Publish a message on the given subject.
@@ -470,7 +457,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// nc.publish("foo", "Hello World!").await?;
     /// # Ok(())
     /// # }
@@ -487,7 +474,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let reply = nc.new_inbox();
     /// let rsub = nc.subscribe(&reply).await?;
     /// nc.publish_request("foo", &reply, "Help me!").await?;
@@ -512,7 +499,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let reply = nc.new_inbox();
     /// let rsub = nc.subscribe(&reply).await?;
     /// # Ok(())
@@ -527,13 +514,12 @@ impl Connection {
     ///
     /// # Example
     /// ```
-    /// # #![feature(async_closure)]
     /// use futures::stream::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let stream = nc.subscribe("foo").await?
-    ///      .with_async_handler( async move |m| { m.respond("ans=42").await?; Ok(()) });
+    ///      .with_async_handler( move |m| async move { m.respond("ans=42").await?; Ok(()) });
     /// let resp = nc.request("foo", "Help me?").await?;
     /// # Ok(())
     /// # }
@@ -549,12 +535,11 @@ impl Connection {
     ///
     /// # Example
     /// ```
-    /// # #![feature(async_closure)]
     /// use futures::stream::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// let nc = nats_aflowt::connect("demo.nats.io").await?;
-    /// nc.subscribe("foo").await?.with_async_handler(async move |m| { m.respond("ans=42").await?; Ok(()) });
+    /// let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
+    /// nc.subscribe("foo").await?.with_async_handler(move |m| async move { m.respond("ans=42").await?; Ok(()) });
     /// let resp = nc.request_timeout("foo", "Help me?", std::time::Duration::from_secs(2)).await?;
     /// # Ok(())
     /// # }
@@ -606,12 +591,11 @@ impl Connection {
     ///
     /// # Example
     /// ```
-    /// # #![feature(async_closure)]
     /// # use futures::stream::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
-    /// # nc.subscribe("foo").await?.with_async_handler( async move |m| { m.respond("ans=42").await?; Ok(()) });
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
+    /// # nc.subscribe("foo").await?.with_async_handler( move |m| async move { m.respond("ans=42").await?; Ok(()) });
     /// let mut sub = nc.request_multi("foo", "What is the answer?").await?.stream();
     /// if let Some(msg) = sub.next().await { /* ... */ }
     /// # Ok(())
@@ -642,7 +626,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// nc.flush().await?;
     /// # Ok(())
     /// # }
@@ -661,7 +645,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// nc.flush().await?;
     /// # Ok(())
     /// # }
@@ -683,7 +667,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// nc.close().await;
     /// # Ok(())
     /// # }
@@ -701,7 +685,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// println!("server rtt: {:?}", nc.rtt().await);
     /// # Ok(())
     /// # }
@@ -747,7 +731,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// println!("ip: {:?}", nc.client_ip().await);
     /// # Ok(())
     /// # }
@@ -785,7 +769,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// println!("ip: {:?}", nc.client_id().await);
     /// # Ok(())
     /// # }
@@ -811,17 +795,17 @@ impl Connection {
     /// # use std::sync::{Arc, atomic::{AtomicBool, Ordering::SeqCst}};
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let received = Arc::new(AtomicBool::new(false));
     /// let received_2 = received.clone();
     ///
-    /// nc.subscribe("test.drain").await?.with_handler(move |m| {
+    /// let h = nc.subscribe("test.drain").await?.with_handler(move |m| {
     ///     received_2.store(true, SeqCst);
     ///     Ok(())
     /// });
     ///
     /// nc.publish("test.drain", "message").await?;
-    /// nc.drain().await?;
+    /// nc.drain().await;
     ///
     /// # tokio::time::sleep(std::time::Duration::from_secs(1)).await;
     ///
@@ -842,7 +826,7 @@ impl Connection {
     /// ```no_run
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// let sub = nc.subscribe("foo.headers").await?;
     /// let headers = [("header1", "value1"),
     ///                ("header2", "value2")].iter().collect();
@@ -874,7 +858,7 @@ impl Connection {
     /// ```
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// let nc = nats_aflowt::connect("demo.nats.io").await?;
+    /// let nc = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// println!("max payload: {:?}", nc.max_payload().await);
     /// # Ok(())
     /// # }
@@ -882,7 +866,7 @@ impl Connection {
         self.0.client.server_info.lock().await.max_payload
     }
 
-    async fn do_subscribe(&self, subject: &str, queue: Option<&str>) -> io::Result<Subscription> {
+    async fn do_subscribe(&self, subject: &str, queue: Option<String>) -> io::Result<Subscription> {
         let (sid, receiver) = self.0.client.subscribe(subject, queue).await?;
         Ok(Subscription::new(
             sid,
@@ -908,6 +892,47 @@ impl Connection {
     }
 }
 
+#[cfg(feature = "otel")]
+static TRACING_STARTED: once_cell::sync::OnceCell<bool> = once_cell::sync::OnceCell::new();
+
+#[cfg(not(feature = "otel"))]
+pub fn init_tracing() {}
+#[cfg(feature = "otel")]
+pub fn init_tracing() {
+    //use tracing_subscriber::layer::SubscriberExt as _;
+    TRACING_STARTED.get_or_init(|| {
+        /*
+        let tracer = opentelemetry_otlp::new_pipeline()
+            .tracing()
+            .with_exporter(
+                opentelemetry_otlp::new_exporter()
+                    .tonic()
+                    .with_endpoint("http://127.0.0.1:4317"),
+            )
+            .install_batch(opentelemetry::runtime::Tokio)
+            .expect("init_tracer");
+         */
+        //let tracer = opentelemetry::global::tracer("ex.com/basic");
+        //let otel_layer = OpenTelemetryLayer::new(tracer);
+        //let subscriber = tracing_subscriber::Registry::default().with(otel_layer);
+
+        //let telemetry = tracing_opentelemetry::layer().with_tracer(tracer);
+        //let subscriber = tracing_subscriber::Registry::default().with(telemetry);
+
+        // a builder for `FmtSubscriber`.
+        let subscriber = tracing_subscriber::FmtSubscriber::builder()
+            // all spans/events with a level higher than TRACE (e.g, debug, info, warn, etc.)
+            // will be written to stdout.
+            .with_max_level(tracing::Level::TRACE)
+            // completes the builder.
+            .finish();
+        tracing::subscriber::set_global_default(subscriber)
+            .expect("failed setting default tracing");
+        tracing::info!("Hello! tracing initialized");
+        true
+    });
+}
+
 /*
 use once_cell::sync::OnceCell;
 static TOKIO_CONSOLE_INIT: OnceCell<bool> = OnceCell::new();
