@@ -20,23 +20,24 @@ use crate::{
     Message, Stream,
 };
 
-use chrono::Utc;
 use futures::{Future, StreamExt};
 use lazy_static::lazy_static;
 use regex::Regex;
 use serde::{Deserialize, Serialize};
-use std::sync::atomic::{AtomicBool, Ordering};
 use std::{
     cmp,
     collections::HashSet,
     io,
     pin::Pin,
-    sync::Arc,
+    sync::{
+        atomic::{AtomicBool, Ordering},
+        Arc,
+    },
     task::{Context, Poll},
     time::Duration,
 };
-use tokio::io::ReadBuf;
-use tokio::sync::Mutex;
+use time::{serde::rfc3339, OffsetDateTime};
+use tokio::{io::ReadBuf, sync::Mutex};
 
 const DEFAULT_CHUNK_SIZE: usize = 128 * 1024;
 const NATS_ROLLUP: &str = "Nats-Rollup";
@@ -74,7 +75,7 @@ fn test_valid_bucket_name() {
     assert!(!is_valid_bucket_name(".99"));
     assert!(!is_valid_bucket_name("99."));
     assert!(!is_valid_bucket_name("*"));
-    assert!(!is_valid_bucket_name("Δ22"));
+    assert!(!is_valid_bucket_name("\u{20ac}")); // "€"
 }
 
 #[test]
@@ -87,7 +88,7 @@ fn test_valid_object_name() {
     assert!(!is_valid_object_name(".99"));
     assert!(!is_valid_object_name("99."));
     assert!(!is_valid_object_name("*"));
-    assert!(!is_valid_object_name("Δ22"));
+    assert!(!is_valid_object_name("\u{20ac}")); // "€"
 }
 
 #[test]
@@ -118,13 +119,13 @@ impl JetStream {
     /// # Example
     ///
     /// ```
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "create_object_store".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -174,20 +175,20 @@ impl JetStream {
     /// # Example
     ///
     /// ```
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
-    /// #
-    /// context.create_object_store(&Config {
-    ///   bucket: "object_store".to_string(),
+    /// # let name = format!("bucket_object_store_{}", rand::random::<u64>());
+    /// let _ = context.create_object_store(&object_store::Config {
+    ///   bucket: name.clone(),
     ///   ..Default::default()
     /// }).await?;
     ///
-    /// let bucket = context.object_store("object_store").await?;
-    ///
-    /// # context.delete_object_store("object_store").await?;
+    /// // retrieve same bucket by its name
+    /// let bucket = context.object_store(&name).await?;
+    /// # context.delete_object_store(&name).await?;
     /// # Ok(())
     /// # }
     /// ```
@@ -220,7 +221,7 @@ impl JetStream {
     /// use nats_aflowt::object_store::Config;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
     /// # let bucket = context.create_object_store(&Config {
@@ -260,6 +261,7 @@ pub struct ObjectInfo {
     /// Number of chunks the object is stored in.
     pub chunks: usize,
     /// Date and time the object was last modified.
+    #[serde(with = "rfc3339")]
     pub modified: DateTime,
     /// Digest of the object stream.
     pub digest: String,
@@ -407,13 +409,13 @@ impl ObjectStore {
     /// # Examples
     ///
     /// ```
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "info".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -428,7 +430,7 @@ impl ObjectStore {
     /// # }
     /// ```
     pub async fn info(&self, object_name: &str) -> io::Result<ObjectInfo> {
-        // LoOkup the stream to get the bound subject.
+        // Lookup the stream to get the bound subject.
         let object_name = sanitize_object_name(object_name);
         if !is_valid_object_name(&object_name) {
             return Err(io::Error::new(
@@ -470,14 +472,14 @@ impl ObjectStore {
     /// # Example
     ///
     /// ```
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # use tokio::io::AsyncReadExt as _;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "put".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -544,7 +546,7 @@ impl ObjectStore {
             chunks: object_chunks,
             size: object_size,
             digest: "".to_string(),
-            modified: Utc::now(),
+            modified: OffsetDateTime::now_utc(),
             deleted: false,
         };
 
@@ -582,13 +584,14 @@ impl ObjectStore {
     /// ```
     /// use std::io::Read as _;
     /// use tokio::io::AsyncReadExt as _;
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// nats_aflowt::init_tracing();
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "get".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -630,13 +633,13 @@ impl ObjectStore {
     ///
     /// ```
     /// use std::io::Read;
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "delete".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -647,9 +650,9 @@ impl ObjectStore {
     /// bucket.delete("foo").await?;
     ///
     /// let info = bucket.info("foo").await?;
-    /// assert!(info.deleted);
-    /// assert_eq!(info.size, 0);
-    /// assert_eq!(info.chunks, 0);
+    /// assert!(info.deleted, "deleted");
+    /// assert_eq!(info.size, 0, "size=0");
+    /// assert_eq!(info.chunks, 0, "chunks=0");
     ///
     /// # context.delete_object_store("delete").await?;
     /// # Ok(())
@@ -692,13 +695,13 @@ impl ObjectStore {
     ///
     /// ```no_run
     /// use futures::stream::StreamExt;
-    /// # use nats_aflowt::object_store::Config;
+    /// # use nats_aflowt::object_store;
     /// # #[tokio::main]
     /// # async fn main() -> std::io::Result<()> {
-    /// # let client = nats_aflowt::connect("demo.nats.io").await?;
+    /// # let client = nats_aflowt::connect("127.0.0.1:14222").await?;
     /// # let context = nats_aflowt::jetstream::new(client);
     /// #
-    /// let bucket = context.create_object_store(&Config {
+    /// let bucket = context.create_object_store(&object_store::Config {
     ///   bucket: "watch".to_string(),
     ///   ..Default::default()
     /// }).await?;
@@ -710,14 +713,14 @@ impl ObjectStore {
     ///
     /// let info = watch.next().await.unwrap();
     /// assert_eq!(info.name, "foo");
-    /// assert_eq!(info.size, bytes.len());
+    /// assert_eq!(info.size, bytes.len(), "foo size");
     ///
     /// let bytes = vec![0];
     /// bucket.put("bar", &mut bytes.as_slice()).await?;
     ///
     /// let info = watch.next().await.unwrap();
     /// assert_eq!(info.name, "bar");
-    /// assert_eq!(info.size, bytes.len());
+    /// assert_eq!(info.size, bytes.len(), "bar size");
     ///
     /// # context.delete_object_store("watch").await?;
     /// # Ok(())
@@ -752,6 +755,7 @@ impl Watch {
     fn into_stream(mut self) -> impl Stream<Item = ObjectInfo> {
         async_stream::stream! {
             while let Some(message) = self.subscription.next().await {
+                //if message.data.is_empty() { break; }
                 yield serde_json::from_slice(&message.data).unwrap();
             }
         }
